simplify.constants.Constants

Package simplify :: Module constants :: Class Constants |
[hide private]
[frames] | no frames]

# Class Constants

source code

Holds constant values.

Class Variables | [hide private]
| version = ``'``1.8.0``'``
| api_base_live_url = ``'``https://api.simplify.com/v1/api``'``
| api_base_sandbox_url = ``'``https://sandbox.simplify.com/v1/api``'``
| oauth_base_url = ``'``https://www.simplify.com/commerce/oauth``'``